@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Dispatcher;
 use vars '$VERSION';
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use Log::Report 'log-report', syntax => 'SHORT';
 use Log::Report::Util qw/parse_locale expand_reasons %reason_code
@@ -28,11 +28,9 @@ sub new(@)
 {   my ($class, $type, $name, %args) = @_;
 
     my $backend
-      = $predef_dispatchers{$type} ? $predef_dispatchers{$type}
-      : $type->isa('Log::Dispatch::Output')
-      ? __PACKAGE__.'::LogDispatch'          # wrapper initializer
-      : $type->isa('Log::Log4perl')
-      ? __PACKAGE__.'::Log4perl'             # wrapper initializer
+      = $predef_dispatchers{$type}          ? $predef_dispatchers{$type}
+      : $type->isa('Log::Dispatch::Output') ? __PACKAGE__.'::LogDispatch'
+      : $type->isa('Log::Log4perl')         ? __PACKAGE__.'::Log4perl'
       : $type;
 
     eval "require $backend";
@@ -42,6 +40,13 @@ sub new(@)
        ->init(\%args);
 }
 
+my %format_reason = 
+  ( LOWERCASE => sub { (lc $_[0]) . ': ' }
+  , UPPERCASE => sub { (uc $_[0]) . ': ' }
+  , UCFIRST   => sub { (ucfirst lc $_[0]) . ': '}
+  , IGNORE    => sub { '' }
+  );
+  
 sub init($)
 {   my ($self, $args) = @_;
     my $mode = $self->_set_mode(delete $args->{mode} || 'NORMAL');
@@ -50,6 +55,12 @@ sub init($)
 
     my $accept = delete $args->{accept} || $default_accept[$mode];
     $self->{needs}  = [ expand_reasons $accept ];
+
+    my $f = delete $args->{format_reason} || 'LOWERCASE';
+    $self->{format_reason} = ref $f eq 'CODE' ? $f : $format_reason{$f}
+        or error __x"illegal format_reason '{format}' for dispatcher",
+             format => $f;
+
     $self;
 }
 
@@ -125,12 +136,13 @@ sub translate($$$)
 
     my $text;
     if($translate)
-    {   $text  = (__$reason)->toString. ': '. $message->toString;
+    {   $text  = $self->{format_reason}->((__$reason)->toString)
+              .  $message->toString;
         $text .= ': ' . strerror($opts->{errno}) if $opts->{errno};
         $text .= "\n";
     }
     else
-    {   $text   = $reason . ': ' . $message->untranslated;
+    {   $text   = $self->{format_reason}->($reason) . $message->untranslated;
         $text  .= ': '. strerror($opts->{errno}) if $opts->{errno};
         $text  .= "\n";
     }
